==> deepin-boot-maker_5.7.10.tar.xz: BUILD/src/translations/deepin-boot-maker_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>Ошибка форматирования диска: Пожалуйста, переформатируйте диск или отключите &quot;Автоматическое сканирование внешних дисков&quot; в Защитнике Windows</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Ошибка форматирования диска: Пожалуйста, переформатируйте диск</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Недостаточно пространства на диске: Убедитесь, что на диске достаточно свободного места</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Ошибка Монтирования Диска: пожалуйста, подключите диск снова или перезагрузите систему, чтобы повторить попытку.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Распаковка образа не удалась: проверьте контрольную сумму образа md5 и убедитесь, что образ корректный.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>Внутренняя Ошибка</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>BootMaker - это простой инструмент для записи файлов системных образов на USB-флешки и другие носители.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>Средство для создания Загрузочного Диска</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>Перетащите файл образа ISO сюда</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>ИЛИ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>Выберите файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>Повторно выберите файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>Недопустимый файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Обнаружение файла ISO, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>Запись, пожалуйста подождите... </translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Не извлекайте диск и не выключайте компьютер во время процесса</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>Съемный диск</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>Съемный диск</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>Создание Загрузочного Диска</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>Перезагрузить сейчас</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>Успешно</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Журнал ошибок будет загружен автоматически для обратной связи. Мы не можем работать над улучшениями без ваших отзывов</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>Отправить Отзыв</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>Послепродажное обслуживание</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>Извините, процесс не удался</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>Процесс не удался</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Проверка данных и безопасное извлечение носителей, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>Выбор раздела</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>Форматирование раздела</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Форматирование сотрёт все данные на разделе, но может увеличить вероятность успеха, пожалуйста, подтвердите это действие перед продолжением</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Форматирование раздела перезапишет все данные, пожалуйста, сделайте резервную копию, прежде чем продолжить.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Ошибка форматирования диска: Пожалуйста, отформатируйте раздел в FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>Нет доступного диска</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>Форматирование раздела</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_6.0.11.tar.xz: BUILD/src/translations/deepin-boot-maker_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="20"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>Ошибка форматирования диска: Пожалуйста, переформатируйте диск или отключите &quot;Автоматическое сканирование внешних дисков&quot; в Защитнике Windows</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="23"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>Ошибка форматирования диска: Пожалуйста, переформатируйте диск</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="28"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>Недостаточно пространства на диске: Убедитесь, что на диске достаточно свободного места</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="31"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>Ошибка Монтирования Диска: пожалуйста, подключите диск снова или перезагрузите систему, чтобы повторить попытку.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="34"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>Распаковка образа не удалась: проверьте контрольную сумму образа md5 и убедитесь, что образ корректный.</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="37"/>
        <source>Internal Error</source>
        <translation>Внутренняя Ошибка</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="69"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>BootMaker - это простой инструмент для записи файлов системных образов на USB-флешки и другие носители.</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="71"/>
        <source>Boot Maker</source>
        <translation>Средство для создания  Загрузочного Диска</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="114"/>
        <source>Drag an ISO image file here</source>
        <translation>Перетащите файл образа ISO сюда</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>OR</source>
        <translation>ИЛИ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="80"/>
        <location filename="../app/view/isoselectview.cpp" line="141"/>
        <source>Select an ISO image file</source>
        <translation>Выберите файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="171"/>
        <source>Next</source>
        <translation>Далее</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="231"/>
        <source>Reselect an ISO image file</source>
        <translation>Повторно выберите файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="191"/>
        <source>Illegal ISO image file</source>
        <translation>Недопустимый файл образа ISO</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="378"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>Обнаружение файла ISO, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="34"/>
        <source>Burning</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="46"/>
        <source>Burning, please wait...</source>
        <translation>Запись, пожалуйста подождите... </translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>Не извлекайте диск и не выключайте компьютер во время процесса</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="68"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="23"/>
        <source>Removable Disk</source>
        <translation>Съемный диск</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="227"/>
        <location filename="../libdbm/util/utils.cpp" line="396"/>
        <source>Removable disk</source>
        <translation>Съемный диск</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="105"/>
        <source>Boot Maker</source>
        <translation>Средство для создания  Загрузочного Диска</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="88"/>
        <source>Reboot now</source>
        <translation>Перезагрузить сейчас</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Successful</source>
        <translation>Успешно</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="174"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>Журнал ошибок будет загружен автоматически для обратной связи. Мы не можем работать над улучшениями без ваших отзывов</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="175"/>
        <source>Submit Feedback</source>
        <translation>Отправить Отзыв</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="198"/>
        <source>After-Sale Services</source>
        <translation>Послепродажное обслуживание</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="213"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="222"/>
        <source>Sorry, process failed</source>
        <translation>Извините, процесс не удался</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="17"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>Проверка данных и безопасное извлечение носителей, пожалуйста, подождите...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="75"/>
        <source>Select a partition</source>
        <translation>Выбор раздела</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="101"/>
        <source>Format the partition</source>
        <translation>Форматирование раздела</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="154"/>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="223"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>Форматирование сотрёт все данные на разделе, но может увеличить вероятность успеха, пожалуйста, подтвердите это действие перед продолжением</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="378"/>
        <location filename="../app/view/usbselectview.cpp" line="385"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation>Вы выбрали ISO-образ на этом USB-накопителе. Форматирование сотрет все ваши файлы. Пожалуйста, повторно выберите файл изображения или отмените форматирование.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="385"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>Форматирование раздела перезапишет все данные, пожалуйста, сделайте резервную копию, прежде чем продолжить.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="404"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>Ошибка форматирования диска: Пожалуйста, отформатируйте раздел в FAT32</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="137"/>
        <source>No disk available</source>
        <translation>Нет доступного диска</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="158"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Format Partition</source>
        <translation>Форматирование раздела</translation>
    </message>
</context>
</TS>
